pari_nftables: PARI data package for number fields
==================================================

Description
-----------

Repackaging of the historical megrez number field tables (errors fixed,
1/10th the size, easier to use).

License
-------

GNU General Public License (GPL version 2 or any later version).


Upstream Contact
----------------

http://pari.math.u-bordeaux.fr/

Dependencies
------------

-  Installation: None
-  Runtime: PARI/GP
